EdgeInfo

Trait EdgeInfo 

pub trait EdgeInfo {
    // Required method
    fn labels(&self) -> &HashMap<String, String>;
}
An ngrok tunnel backing an edge. Since labels may be dynamically defined via the dashboard or API, the url and protocol for the tunnel is not knowable ahead of time.

Required Methods

fn labels(&self) -> &HashMap<String, String>

Returns the labels that the tunnel was started with.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors