Tunnel

Trait Tunnel 

pub trait Tunnel:
    Stream<Item = Result<Self::Conn, AcceptError>>
    + TunnelInfo
    + TunnelCloser
    + Unpin
    + Send
    + 'static {
    type Conn: Conn;
}
An ngrok tunnel.

ngrok Tunnels act like TCP listeners and can be used as a [futures::stream::TryStream] of [Conn]ections from endpoints created on the ngrok service.

Required Associated Types

type Conn: Conn

The type of connection associated with this tunnel type. Agent-initiated http, tls, and tcp tunnels all produce EndpointConns, while labeled tunnels produce EdgeConns.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors