pub trait EdgeInfo {
// Required method
fn labels(&self) -> &HashMap<String, String>;
}Expand description
An ngrok tunnel backing an edge. Since labels may be dynamically defined via the dashboard or API, the url and protocol for the tunnel is not knowable ahead of time.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".